==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <source>...</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Zeichentabelle</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Text</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+31"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+4"/>
        <source>Draw text</source>
        <translation>Text einfügen</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="-34"/>
        <source>Contents:</source>
        <translation>Inhalt:</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Standardwert:</translation>
    </message>
    <message>
        <location line="+255"/>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Aus&amp;schneiden</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>Ein&amp;fügen</translation>
    </message>
    <message>
        <location line="+506"/>
        <source>Degree</source>
        <translation>Grad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Diameter</source>
        <translation>Durchmesser</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Fast gleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplikation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Einfacher Text
(Eine Linie, keine Formatierung)</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location line="+234"/>
        <source>Attribute Details</source>
        <translation>Attributdetails</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Bezeichnung:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Aufforderung:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Line Spacing Factor</source>
        <translation>Linienabstand Faktor</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Rotationswinkel</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location line="+85"/>
        <source>Top Center</source>
        <translation>Oben zentriert</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Base Left</source>
        <translation>Basis links</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Left</source>
        <translation>Open links</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Base Center</source>
        <translation>Basis zentriert</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Base Right</source>
        <translation>Basis rechts</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Top Right</source>
        <translation>Oben rechts</translation>
    </message>
    <message>
        <location line="-323"/>
        <source>Bottom Center</source>
        <translation>Unten zentriert</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Middle Left</source>
        <translation>Mitte links</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Middle Center</source>
        <translation>Mitte zentriert</translation>
    </message>
    <message>
        <location line="-163"/>
        <source>Middle Right</source>
        <translation>Mitte rechts</translation>
    </message>
    <message>
        <location line="-96"/>
        <source>Bottom Left</source>
        <translation>Unten links</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Bottom Right</source>
        <translation>Unten rechts</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="-506"/>
        <source>&amp;Bold</source>
        <translation>&amp;Fett</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Tiefgestellt</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Hochgestellt</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Farbe...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Sonderzeichen...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Andere...</translation>
    </message>
    <message>
        <location line="+130"/>
        <source>Plus-Minus</source>
        <translation>Plus-Minus</translation>
    </message>
    <message>
        <source>Allmost equal</source>
        <translation type="obsolete">Fast gleich</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Identity</source>
        <translation>Identität</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Ungleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Quadrat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kubik</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="-1018"/>
        <source>Main Font</source>
        <translation>Hauptschriftart</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Text Height in Drawing Units</source>
        <translation>Texthöhe</translation>
    </message>
    <message>
        <source>1.0</source>
        <translation type="obsolete">1.0</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: qt_de.ts--
Kursiv
&amp;Kursiv</translatorcomment>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Rich Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Test passt auf eine Zeile und hat keine Formatierungen</translation>
    </message>
    <message>
        <source>Simple Text</source>
        <translation type="obsolete">Einfacher Text</translation>
    </message>
    <message>
        <source>0.25</source>
        <translation type="obsolete">0.25</translation>
    </message>
    <message>
        <source>0.5</source>
        <translation type="obsolete">0.5</translation>
    </message>
    <message>
        <source>1.5</source>
        <translation type="obsolete">1.5</translation>
    </message>
    <message>
        <source>2.0</source>
        <translation type="obsolete">2.0</translation>
    </message>
    <message>
        <source>2.5</source>
        <translation type="obsolete">2.5</translation>
    </message>
    <message>
        <source>3.0</source>
        <translation type="obsolete">3.0</translation>
    </message>
    <message>
        <source>5.0</source>
        <translation type="obsolete">5.0</translation>
    </message>
    <message>
        <source>10.0</source>
        <translation type="obsolete">10.0</translation>
    </message>
    <message>
        <source>12.5</source>
        <translation type="obsolete">12.5</translation>
    </message>
    <message>
        <source>15.0</source>
        <translation type="obsolete">15.0</translation>
    </message>
    <message>
        <source>20.0</source>
        <translation type="obsolete">20.0</translation>
    </message>
    <message>
        <location line="+195"/>
        <source>Ctrl+B</source>
        <translation>Ctrl-F</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl-I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Symbol einfügen...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Quelltext</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Text Geometry</source>
        <translation>Textgeometrie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Linienabstand:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Dialog</name>
    <message>
        <source>...</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Zeichentabelle</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Text</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+37"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <source>10</source>
        <translation type="obsolete">10</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+4"/>
        <source>Draw text</source>
        <translation>Text einfügen</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="-40"/>
        <source>Contents:</source>
        <translation>Inhalt:</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Standardwert:</translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Wiederherstellen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>Aus&amp;schneiden</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>Ein&amp;fügen</translation>
    </message>
    <message>
        <location line="+506"/>
        <source>Degree</source>
        <translation>Grad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Diameter</source>
        <translation>Durchmesser</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Fast gleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplikation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No-break space</source>
        <translation>Geschütztes Leerzeichen</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Einfacher Text
(Eine Linie, keine Formatierung)</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location line="+234"/>
        <source>Attribute Details</source>
        <translation>Attributdetails</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Bezeichnung:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Aufforderung:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Wert:</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Line Spacing Factor</source>
        <translation>Linienabstand Faktor</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Winkel:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Rotationswinkel</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="obsolete">0</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Ausrichtung</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Top Center</source>
        <translation>Oben zentriert</translation>
    </message>
    <message>
        <location line="+145"/>
        <source>Base Left</source>
        <translation>Basis links</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>Oben links</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>Basis zentriert</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>Basis rechts</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Top Right</source>
        <translation>Oben rechts</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Center</source>
        <translation>Unten zentriert</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Middle Left</source>
        <translation>Mitte links</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Middle Center</source>
        <translation>Mitte zentriert</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Middle Right</source>
        <translation>Mitte rechts</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Left</source>
        <translation>Unten links</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Bottom Right</source>
        <translation>Unten rechts</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="-513"/>
        <source>&amp;Bold</source>
        <translation>&amp;Fett</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>&amp;Kursiv</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Tiefgestellt</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Hochgestellt</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>&amp;Farbe...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>&amp;Sonderzeichen...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Andere...</translation>
    </message>
    <message>
        <location line="+132"/>
        <source>Plus-Minus</source>
        <translation>Plus-Minus</translation>
    </message>
    <message>
        <source>Allmost equal</source>
        <translation type="obsolete">Fast gleich</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Identity</source>
        <translation>Identität</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Ungleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Quadrat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kubik</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="-982"/>
        <source>Main Font</source>
        <translation>Hauptschriftart</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Text Height in Drawing Units</source>
        <translation>Texthöhe</translation>
    </message>
    <message>
        <source>1.0</source>
        <translation type="obsolete">1.0</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: qt_de.ts--
Kursiv
&amp;Kursiv</translatorcomment>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Rich Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Test passt auf eine Zeile und hat keine Formatierungen</translation>
    </message>
    <message>
        <source>Simple Text</source>
        <translation type="obsolete">Einfacher Text</translation>
    </message>
    <message>
        <source>0.25</source>
        <translation type="obsolete">0.25</translation>
    </message>
    <message>
        <source>0.5</source>
        <translation type="obsolete">0.5</translation>
    </message>
    <message>
        <source>1.5</source>
        <translation type="obsolete">1.5</translation>
    </message>
    <message>
        <source>2.0</source>
        <translation type="obsolete">2.0</translation>
    </message>
    <message>
        <source>2.5</source>
        <translation type="obsolete">2.5</translation>
    </message>
    <message>
        <source>3.0</source>
        <translation type="obsolete">3.0</translation>
    </message>
    <message>
        <source>5.0</source>
        <translation type="obsolete">5.0</translation>
    </message>
    <message>
        <source>10.0</source>
        <translation type="obsolete">10.0</translation>
    </message>
    <message>
        <source>12.5</source>
        <translation type="obsolete">12.5</translation>
    </message>
    <message>
        <source>15.0</source>
        <translation type="obsolete">15.0</translation>
    </message>
    <message>
        <source>20.0</source>
        <translation type="obsolete">20.0</translation>
    </message>
    <message>
        <location line="+195"/>
        <source>Ctrl+B</source>
        <translation>Ctrl-F</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl-I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Symbol einfügen...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Quelltext</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Text Geometry</source>
        <translation>Textgeometrie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Linienabstand:</translation>
    </message>
</context>
</TS>
